==> wizzi-web-0.7.5.tgz: package/readme.md <==
# wizzi-web

A wizzi default plugin for html css svg markdown

## Work still in progress

Availability of features will be announced
on [Twitter](https://twitter.com/wizziteam) and [Facebook](https://www.facebook.com/wizzifactory)

## Features
### Implemented Wizzi models

<table>
<tr>
<th>Schema</th>
<th>Descriptionn</th>
<th>Builtin</th>
<th>Model transformers</th>
<th>Artifacts</th>
</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/html.wfschema.ittf>html</a><td>Html wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>html/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/css.wfschema.ittf>css</a><td>Cascading style sheet wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>css/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/scss.wfschema.ittf>scss</a><td>Sass cascading style sheet wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>scss/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/svg.wfschema.ittf>svg</a><td>Scalable Vector Graphics wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>svg/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/md.wfschema.ittf>md</a><td>Markdown wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>md/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/graphql.wfschema.ittf>graphql</a><td>Graphql wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/site.wfschema.ittf>site</a><td>Components of a website structure</td>
<td>
no<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/vtt.wfschema.ittf>vtt</a><td>Video Text Tracks specification</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>vtt/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/vue.wfschema.ittf>vue</a><td>Vue wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>vue/document</td>
</tr>
</table>

</tr>
</table>



<p>Wizzi plugins are documented <a href="https://wizzifactory.github.io/docs/wizziplugins.html">here</a>.</p>



<p>You can find a few samples in the /examples folder, but you can find more in the <a href="https://github.com/wizzifactory/wizzi/tree/master/packages/wizzi-demo/.wizzi/ittf/examples/advanced/plugins">demo package</a>.</p>

## Source and generation
wizzi-web is generated using the Wizzi factory ver 0.7

## The Wizzi Factory

A model driven artifact factory.


<p><a href="https://wizzifactory.github.io/">Project page</a></p>

## Built With
* [Nodejs](https://nodejs.org)

* [Wizzi Factory](https://github.com/wizzifactory)


## License

<p>This project is licensed under the MIT License - see the <a href="license.txt">license.txt</a> for details.</p>

==> wizzi-web-0.7.10.tgz: package/readme.md <==
# wizzi-web

A Wizzi Core Plugin for html css svg markdown

## Work still in progress

Availability of features will be announced
on [Twitter](https://twitter.com/wizziteam) and [Facebook](https://www.facebook.com/wizzifactory)

## Features
### Implemented Wizzi Models

<table>
<tr>
<th>Schema</th>
<th>Descriptionn</th>
<th>Builtin</th>
<th>Model transformers</th>
<th>Artifacts</th>
</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/html.wfschema.ittf>html</a><td>Html wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>html/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/css.wfschema.ittf>css</a><td>Cascading style sheet wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>css/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/scss.wfschema.ittf>scss</a><td>Sass cascading style sheet wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>scss/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/svg.wfschema.ittf>svg</a><td>Scalable Vector Graphics wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>svg/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/md.wfschema.ittf>md</a><td>Markdown wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>md/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/graphql.wfschema.ittf>graphql</a><td>Graphql wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>graphql/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/site.wfschema.ittf>site</a><td>Components of a website structure</td>
<td>
no<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/vtt.wfschema.ittf>vtt</a><td>Video Text Tracks specification</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>vtt/document</td>
</tr>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/graphql/.wizzi/ittf/lib/wizzi/schemas/vue.wfschema.ittf>vue</a><td>Vue wizzi language model</td>
<td>
no<td>

<table>
</table>

<td>

<table>
<tr>
<td>vue/document</td>
</tr>
</table>

</tr>
</table>



<p>Wizzi Plugins are documented <a href="https://wizzifactory.github.io/docs/wizziplugins.html">here</a>.</p>



<p>You can find a few samples in the /examples folder, but you can find more in the <a href="https://github.com/wizzifactory/wizzi/tree/master/packages/wizzi-demo/.wizzi/ittf/examples/advanced/plugins">demo package</a>.</p>

## Source and generation
wizzi-web is generated using the Wizzi factory ver 0.7

## Wizzi

One machinery, many productions.


<p><a href="https://stfnbssl.github.io/wizzi">Project page</a></p>

## Built With
* [Nodejs](https://nodejs.org)

* [Wizzi Factory](https://github.com/wizzifactory)


## License

<p>This project is licensed under the MIT License - see the <a href="license.txt">license.txt</a> for details.</p>
